/*
 * Copyright (c) 2018 by iTAS Innovations Pvt. Ltd.
 * All rights reserved.
 *
 *          %name: cyfxmain.h %
 *       %version: 1 %
 * %date_modified: wed Dec 19 11:18:57 2018 %
 *    %derived_by: itasin %
 *          Owner: itasin
 *         Author: Thrimurthi M
 */
#ifndef _INCLUDED_CYFXMAIN_H_
#define _INCLUDED_CYFXMAIN_H_

#include "cyu3types.h"
#include "cyu3usbconst.h"
#include "cyu3externcstart.h"
#include "cyu3dma.h"


/****************************************************************************
 * Macros and types
 ****************************************************************************/

#define CY_FX_I2CLP_DMA_BUF_COUNT      (2)                       /* I2C loop channel buffer count */
#define CY_FX_FIFOLP_DMA_BUF_COUNT      (4)                       /* FIFO loop channel buffer count */
#define CY_FX_FIFOLP_DMA_TX_SIZE        (0)                    /* DMA transfer size is set to infinite */
#define CY_FX_I2CLP_DMA_TX_SIZE        (0)                       /* DMA transfer size is set to infinite */
#define CY_FX_DMA_BUF_SIZE              (16)               /* Size of each DMA buffer. This should ideally be set to 16X the EP burst size. */
#define CY_FX_P3LP_THREAD_STACK       (0x1000)                  /* I2C loop application thread stack size */
#define CY_FX_P3LP_THREAD_PRIORITY    (8)                       /* I2C loop application thread priority */

// GPIO Pin Definition
#define Demod_RST    (23)
#define Tuner_GPIO    (27)

// End point definition
#define CY_FX_EP_PRODUCER               0x01    /* EP 1 OUT */
#define CY_FX_EP_CONSUMER_1             0x81    /* EP 1 IN */
#define CY_FX_EP_CONSUMER_2             0x82    /* EP 2 IN */

//  Socket Definition
#define CY_FX_EP_UtoI2C_PRODUCER_SOCKET        CY_U3P_UIB_SOCKET_PROD_1    /* USB Socket 1 is producer for I2C */
#define CY_FX_EP_I2CtoU_CONSUMER_SOCKET        CY_U3P_UIB_SOCKET_CONS_1    /* USB Socket 1 is consumer for I2C */
#define CY_FX_TS_CONSUMER_USB_SOCKET              CY_U3P_UIB_SOCKET_CONS_2    /* USB Socket 2 is consumer for TS */
#define CY_FX_PRODUCER_PPORT_SOCKET_0          CY_U3P_PIB_SOCKET_0    /* P-port Socket 0 is producer for TS */
#define CY_FX_PRODUCER_PPORT_SOCKET_1		   CY_U3P_PIB_SOCKET_1    /* P-port Socket 1 is producer for TS */

uint8_t copyBuffer[1024];         /* Global Buffer for I2C Read and write operation */

/* functions in  P3 interface  */

/* Function    : TD_Poll
   Description :  when loop back application is active, continuously monitoring the data at end point 0x01.
   Parameters  : void
 */
void TD_Poll(void);


/* Function    : End_Point_In_Buff
   Description : Get the Data from USB (End point 0x01).
   Parameters  : void
   Return value: CY_U3P_SUCCESS or ERROR code defined in CyU3PDmaChannelDiscardBuffer and CyU3PDmaChannelGetBuffer.
 */
extern CyU3PReturnStatus_t
 End_Point_In_Buff();


/* Function    : End_Point_Out_Buff
   Description : commit the Data from demod to USB (end point 0x81).
   Parameters  :
    			InBuf_count - The number of byte received from demod.
   Return value: NULL
 */
void End_Point_Out_Buff(uint32_t OutBuf_count );

/* Extern definitions for the USB Descriptors */
extern const uint8_t CyFxUSB20DeviceDscr[];
extern const uint8_t CyFxUSB30DeviceDscr[];
extern const uint8_t CyFxUSBDeviceQualDscr[];
extern const uint8_t CyFxUSBFSConfigDscr[];
extern const uint8_t CyFxUSBHSConfigDscr[];
extern const uint8_t CyFxUSBBOSDscr[];
extern const uint8_t CyFxUSBSSConfigDscr[];
extern const uint8_t CyFxUSBStringLangIDDscr[];
extern const uint8_t CyFxUSBManufactureDscr[];
extern const uint8_t CyFxUSBProductDscr[];

#include "cyu3externcend.h"

#endif /* _INCLUDED_CYFXMAIN_H_ */

/*[]*/

