/*
 * Copyright (c) 2018 by iTAS Innovations Pvt. Ltd.
 * All rights reserved.
 *
 *          %name: i2c.c %
  *       %version: 1 %
 * %date_modified: wed Dec 19 11:18:57 2018 %
 *    %derived_by: itasin %
 *          Owner: itasin
 *         Author: Thrimurthi M
 */

#include "cyu3error.h"
#include "cyfxmain.h"
#include "cyu3uart.h"
#include "cyu3i2c.h"
#include "i2c.h"
#include <cyu3gpio.h>


CyU3PReturnStatus_t PrI2CRd(uint8_t slaveAddr,
		uint32_t count,
		uint8_t *buf)
{
	CyU3PReturnStatus_t status = CY_U3P_SUCCESS;
	CyU3PI2cPreamble_t preamble;

	CyU3PDebugPrint (2, "I2C Read Operation - dev: 0x%x, size: 0x%x,\r\n",slaveAddr, count);

	/* Update the preamble information. */
	preamble.length    = 1;
	preamble.buffer[0] = ((slaveAddr<< 1) | I2C_Operation_Read);
	preamble.ctrlMask  = 0x0000;

	status = CyU3PI2cReceiveBytes (&preamble, buf,count , 100);

	if (status != CY_U3P_SUCCESS)
	{
		return status;
	}
	return CY_U3P_SUCCESS;
}

CyU3PReturnStatus_t PrI2CWr (  uint8_t slaveAddr,
		uint32_t count,
		uint8_t *buf)
{
	CyU3PReturnStatus_t status = CY_U3P_SUCCESS;
	CyU3PI2cPreamble_t preamble;

	CyU3PDebugPrint (1, "I2C Write operation - dev:0x%x, size: %d,\r\n",slaveAddr, count);

	/* Update the preamble information. */
	preamble.length    = 1;
	preamble.buffer[0] = ((slaveAddr<< 1) | I2C_Operation_Write );
	preamble.ctrlMask  = 0x0000;

	status = CyU3PI2cTransmitBytes (&preamble, buf, count, 1000);

	if (status != CY_U3P_SUCCESS)
	{
		return status;
	}
	/* Wait for the write to complete. */
	preamble.length = 1;

	status = CyU3PI2cWaitForAck(&preamble, 1000);
	if (status != CY_U3P_SUCCESS)
	{
		return status;
	}
	/* An additional delay seems to be required after receiving an ACK. */
	CyU3PThreadSleep (1);

	return CY_U3P_SUCCESS;
}

CyU3PReturnStatus_t TunerI2CRd(uint8_t slaveAddr,
		uint8_t MemAddr,
		uint32_t count,
		uint8_t *buf)
{
	CyU3PReturnStatus_t status = CY_U3P_SUCCESS;
	CyU3PI2cPreamble_t preamble;

	CyU3PDebugPrint (2, "I2C Read Operation - dev: 0x%x, size: 0x%x,\r\n",slaveAddr, count);

	/* Update the preamble information. */
	preamble.length    = 3;
	preamble.buffer[0] = ((slaveAddr<< 1) | I2C_Operation_Write);
	preamble.buffer[1]=MemAddr;
	preamble.buffer[2] = ((slaveAddr<< 1) | I2C_Operation_Read);
	preamble.ctrlMask  = 0x0002;

	status = CyU3PI2cReceiveBytes (&preamble, buf,count , 100);

	if (status != CY_U3P_SUCCESS)
	{
		return status;
	}
	return CY_U3P_SUCCESS;
}

CyU3PReturnStatus_t TunerI2CWr (  uint8_t slaveAddr,
		uint8_t MemAddr,
		uint32_t count,
		uint8_t *buf)
{
	CyU3PReturnStatus_t status = CY_U3P_SUCCESS;
	CyU3PI2cPreamble_t preamble;

	CyU3PDebugPrint (1, "I2C Write operation - dev:0x%x, size: %d,\r\n",slaveAddr, count);

	/* Update the preamble information. */
	preamble.length    = 2;
	preamble.buffer[0] = ((slaveAddr<< 1) | I2C_Operation_Write );
	preamble.buffer[1] = MemAddr;
	preamble.ctrlMask  = 0x0000;

	status = CyU3PI2cTransmitBytes (&preamble, buf, count, 1000);

	if (status != CY_U3P_SUCCESS)
	{
		return status;
	}
	/* Wait for the write to complete. */
	preamble.length = 1;

	status = CyU3PI2cWaitForAck(&preamble, 1000);
	if (status != CY_U3P_SUCCESS)
	{
		return status;
	}
	/* An additional delay seems to be required after receiving an ACK. */
	CyU3PThreadSleep (1);

	return CY_U3P_SUCCESS;
}


void TD_Poll(void)
{

	CyU3PReturnStatus_t status = CY_U3P_SUCCESS;

	/* Get Data from USB IN END Point */
	if(End_Point_In_Buff()==CY_U3P_SUCCESS)
	{
		uint32_t byte_count;
		uint8_t devAddr;
		uint8_t MemAddr;


		/* I2C Demod_Read operation */
		if (copyBuffer[0] == I2C_DEMOD_RD_CMD)
		{
			devAddr= copyBuffer[1];
			byte_count = copyBuffer[3];
			byte_count = ((byte_count<<8)|copyBuffer[2]);

			status = PrI2CRd(devAddr,byte_count,copyBuffer);

			if (status == CY_U3P_SUCCESS)
			{
#if 0
				CyU3PDebugPrint (4, "byte_count= 0x%x\r\n",byte_count);
				for(int x=0;x<byte_count; x++)
				{
					CyU3PDebugPrint (4, "Read Buffer[%d] = 0x%x\r\n",x,copyBuffer[x]);
				}
#endif
				/* Put data to USB OUT END Point */
				End_Point_Out_Buff(byte_count);
			}
			else
			{
				CyU3PDebugPrint (4, "%x: I2C P3 Read Application failed to initialize. Error code: %d.\r\n", status);
			}
		}
		/* I2C Demod_Write operation */
		else if ( copyBuffer[0] == I2C_DEMOD_WR_CMD)
		{
			devAddr= copyBuffer[1];
			byte_count = copyBuffer[3];
			byte_count = ((byte_count<<8)|copyBuffer[2]);

			status = PrI2CWr(devAddr,byte_count,(copyBuffer+I2C_DEMOD_Offset));

			if(status!=CY_U3P_SUCCESS)
			{
				CyU3PDebugPrint (4, "%x: I2C P3 Write Application failed to initialize. Error code: %d.\r\n", status);
			}
		}

		/* I2C Tuner_Read operation */
				if (copyBuffer[0] == I2C_TUNER_RD_CMD)
				{
					devAddr= copyBuffer[1];
					byte_count = copyBuffer[3];
					byte_count = ((byte_count<<8)|copyBuffer[2]);
					MemAddr= copyBuffer[4];

					status = TunerI2CRd(devAddr,MemAddr,byte_count,copyBuffer);

					if (status == CY_U3P_SUCCESS)
					{
		#if 0
						CyU3PDebugPrint (4, "byte_count= 0x%x\r\n",byte_count);
						for(int x=0;x<byte_count; x++)
						{
							CyU3PDebugPrint (4, "Read Buffer[%d] = 0x%x\r\n",x,copyBuffer[x]);
						}
		#endif
						/* Put data to USB OUT END Point */
						End_Point_Out_Buff(byte_count);
					}
					else
					{
						CyU3PDebugPrint (4, "%x: I2C Tuner Read Application failed to initialize. Error code: %d.\r\n", status);
					}
				}
				/* I2C Write operation */
				else if ( copyBuffer[0] == I2C_TUNER_WR_CMD)
				{
					devAddr= copyBuffer[1];
					byte_count = copyBuffer[3];
					byte_count = ((byte_count<<8)|copyBuffer[2]);
					MemAddr = copyBuffer[4];

					status = TunerI2CWr(devAddr,MemAddr,byte_count,(copyBuffer+I2C_TUNER_Offset));

					if(status!=CY_U3P_SUCCESS)
					{
						CyU3PDebugPrint (4, "%x: I2C Tuner Write Application failed to initialize. Error code: %d.\r\n", status);
					}
				}

	}
}

