/*
 * Copyright (c) 2018 by iTAS Innovations Pvt. Ltd.
 * All rights reserved.
 *
 *          %name: i2c.h %
 *       %version: 1 %
 * %date_modified: wed Dec 19 11:18:57 2018 %
 *    %derived_by: itasin %
 *          Owner: itasin
 *         Author: Thrimurthi M
 */

#ifndef _INCLUDED_I2C_H_
#define _INCLUDED_I2C_H_

#include <cyu3types.h>

/****************************************************************************
 * Macros and types
 ****************************************************************************/

#define I2C_Operation_Write               ((uint8_t)0)    /*< Write operation */
#define I2C_Operation_Read                ((uint8_t)1)    /*!< Read operation */
#define I2C_DEMOD_Offset                    (4)             /* Offset of Demod both data and Header from PC */
#define I2C_DEMOD_WR_CMD                    (0x55)         /* Demod Memory Read command Address*/
#define I2C_DEMOD_RD_CMD                    (0xAA)          /* Demod Memory Write command Address*/
#define I2C_TUNER_Offset                    (5)             /* Offset of Tuner data from PC */
#define I2C_TUNER_WR_CMD                    (0x14)         /* Demod Memory Read command Address*/
#define I2C_TUNER_RD_CMD                    (0x15)          /* Demod Memory Write command Address*/
#define CY_FX_USBI2C_I2C_BITRATE           (400000)         /* I2C Data rate */


/* Function    : PrI2CWr
   Description : Write arbitrary amount of data to Demodulator over I2C interface.
   Parameters  :
                 slaveAddr - I2C slave address for the Demod or tuner.
                 count     - Size of data write data in bytes.
                 buf       - Pointer to buffer containing data.
   Return value: CY_U3P_SUCCESS or fails with an error defined in cyu3error.h
 */
extern CyU3PReturnStatus_t
PrI2CWr (
        uint8_t slaveAddr,
        uint32_t count,
        uint8_t *buf);


/* Function    : PrI2CRd
   Description : Readarbitrary amount of data to Demodulator over I2C interface.
   Parameters  :
                 slaveAddr - I2C slave address for the Demod or tuner.
                 count     = Size of data to be read in bytes.
                 buf       - Buffer to be filled with data
   Return value: CY_U3P_SUCCESS or fails with an error defined in cyu3error.h
 */
extern CyU3PReturnStatus_t
PrI2CRd (
        uint8_t slaveAddr,
        uint32_t count,
        uint8_t *buf);

/* Function    : TunerI2CWr
   Description : Write arbitrary amount of data to tuner  over I2C interface.
   Parameters  :
                 slaveAddr - I2C slave address for the Demod or tuner.
                 MemAddr  -  Byte of memory address being written to.
                 count     - Size of data write data in bytes.
                 buf       - Pointer to buffer containing data.
   Return value: CY_U3P_SUCCESS or fails with an error defined in cyu3error.h
 */
extern CyU3PReturnStatus_t
TunerI2CWr (
        uint8_t slaveAddr,
        uint8_t MemAddr,
        uint32_t count,
        uint8_t *buf);


/* Function    : TunerI2CRd
   Description : Read arbitrary amount of data to tuner  over I2C interface.
   Parameters  :
                 slaveAddr - I2C slave address for the Demod or tuner.
                 count     - Size of data to be read in bytes.
                 MemAddr -  Byte of memory address being written to.
                 buf       - Buffer to be filled with data
   Return value: CY_U3P_SUCCESS or fails with an error defined in cyu3error.h
 */
extern CyU3PReturnStatus_t
TunnerI2CRd (
        uint8_t slaveAddr,
        uint32_t count,
        uint8_t MemAddr,
        uint8_t *buf);


#endif /* _INCLUDED_I2C_H_ */
